@@ -18,7 +18,7 @@ BEGIN {
 
 use Exporter ();
 use vars qw($VERSION @ISA @EXPORT @EXPORT_OK);
-$VERSION   = '2.10_004';
+$VERSION   = '2.10_005';
 $VERSION   = eval $VERSION;
 @ISA       = qw(Exporter);
 @EXPORT    = qw(mkpath rmtree);
@@ -96,7 +96,24 @@ sub mkpath {
         $arg->{mode} = defined $mode ? $mode : oct '777';
     }
     else {
+        my %args_permitted = map { $_ => 1 } ( qw|
+            chmod
+            error
+            group
+            mask
+            mode
+            owner
+            uid
+            user
+            verbose
+        | );
+        my @bad_args = ();
         $arg = pop @_;
+        for my $k (sort keys %{$arg}) {
+            push @bad_args, $k unless $args_permitted{$k};
+        }
+        _croak("Unrecognized option(s) passed to make_path(): @bad_args")
+            if @bad_args;
         $arg->{mode} = delete $arg->{mask} if exists $arg->{mask};
         $arg->{mode} = oct '777' unless exists $arg->{mode};
         ${ $arg->{error} } = [] if exists $arg->{error};
@@ -239,7 +256,20 @@ sub rmtree {
         }
     }
     else {
+        my %args_permitted = map { $_ => 1 } ( qw|
+            error
+            keep_root
+            result
+            safe
+            verbose
+        | );
+        my @bad_args = ();
         $arg = pop @_;
+        for my $k (sort keys %{$arg}) {
+            push @bad_args, $k unless $args_permitted{$k};
+        }
+        _croak("Unrecognized option(s) passed to remove_tree(): @bad_args")
+            if @bad_args;
         ${ $arg->{error} }  = [] if exists $arg->{error};
         ${ $arg->{result} } = [] if exists $arg->{result};
         $paths = [@_];
@@ -1050,6 +1080,27 @@ to examining directory trees.
 
 =head1 BUGS AND LIMITATIONS
 
+The following describes F<File::Path> limitations and how to report bugs.
+
+=head2 MULTITHREAD APPLICATIONS
+
+F<File::Path> B<rmtree> and B<remove_tree> will not work with multithreaded
+applications due to its use of B<chdir>.  At this time, no warning or error
+results and you will certainly encounter unexpected results.
+
+The implementation that surfaces this limitation may change in a future
+release.
+
+=head2 NFS Mount Points
+
+F<File::Path> is not responsible for triggering the automounts, mirror mounts,
+and the contents of network mounted filesystems.  If your NFS implementation
+requires an action to be performed on the filesystem in order for
+F<File::Path> to perform operations, it is strongly suggested you assure
+filesystem availability by reading the root of the mounted filesystem.
+
+=head2 REPORTING BUGS
+
 Please report all bugs on the RT queue, either via the web interface:
 
 L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=File-Path>
